@@ -26,8 +26,8 @@ fn _get_partitions(physical: bool) -> Result<Vec<Disks>, Error> {
         vdisks.push(Disks {
             name: name.to_owned(),
             mount_point: path.to_owned(),
-            total_space: usage.0 / 100000,
-            avail_space: usage.1 / 100000,
+            total_space: usage.0 / (1024 * 1024),
+            avail_space: usage.1 / (1024 * 1024),
         });
         line.clear()
     }
@@ -35,22 +35,14 @@ fn _get_partitions(physical: bool) -> Result<Vec<Disks>, Error> {
     Ok(vdisks)
 }
 
-/// Return a Vec of [Disks] (physical and virtual) with their minimal informations.
-///
-/// Contains `name`, `mount_point` and `total`/`free` space.
-///
-/// On linux it will get them from `/proc/mounts`.
+/// Return a Vec of [Disks] (physical and virtual) with their minimal information.
 ///
 /// [Disks]: ../disks/struct.Disks.html
 pub fn get_partitions() -> Result<Vec<Disks>, Error> {
     _get_partitions(false)
 }
 
-/// Return a Vec of [Disks] (physical) with their minimal informations.
-///
-/// Contains `name`, `mount_point` and `total`/`free` space.
-///
-/// On linux it will get them from `/proc/mounts`.
+/// Return a Vec of [Disks] (physical) with their minimal information.
 ///
 /// [Disks]: ../disks/struct.Disks.html
 pub fn get_partitions_physical() -> Result<Vec<Disks>, Error> {
