@@ -36,34 +36,25 @@ fn _get_partitions(physical: bool) -> Result<Vec<Disks>, Error> {
             Ok(val) => val,
             Err(x) => return Err(x),
         };
-        // TODO - Check if the / 100000 is correct
         vdisks.push(Disks {
             name: to_str(stat.f_mntfromname.as_ptr()).to_owned(),
             mount_point: path.to_owned(),
-            total_space: usage.0 / 100000,
-            avail_space: usage.1 / 100000,
+            total_space: usage.0 / (1024 * 1024),
+            avail_space: usage.1 / (1024 * 1024),
         });
     }
 
     Ok(vdisks)
 }
 
-/// Return a Vec of [Disks] (physical and virtual) with their minimal informations.
-///
-/// Contains `name`, `mount_point` and `total`/`free` space.
-///
-/// On macOS it will use an unsafe call to `getfsstat64`.
+/// Return a Vec of [Disks] (physical and virtual) with their minimal information.
 ///
 /// [Disks]: ../disks/struct.Disks.html
 pub fn get_partitions() -> Result<Vec<Disks>, Error> {
     _get_partitions(false)
 }
 
-/// Return a Vec of [Disks] (physical) with their minimal informations.
-///
-/// Contains `name`, `mount_point` and `total`/`free` space.
-///
-/// On macOS it will use an unsafe call to `getfsstat64`.
+/// Return a Vec of [Disks] (physical) with their minimal information.
 ///
 /// [Disks]: ../disks/struct.Disks.html
 pub fn get_partitions_physical() -> Result<Vec<Disks>, Error> {
