@@ -8,29 +8,23 @@ use std::time::Duration;
 
 /// Get some basic [HostInfo] of the host.
 ///
-/// On linux and macOS it will get the `os_version` and `hostname` from uname.
-///
-/// For the `uptime`/`loadavg`/`memory` on linux it will get them from sysinfo.
-/// But on macOS it will use the crate [get_loadavg] and [get_memory] and a special get_uptime function using an unsafe syscall.
-///
-/// [get_loadavg]: ../cpu/fn.get_loadavg.html
-/// [get_memory]: ../memory/fn.get_memory.html
 /// [HostInfo]: ../host/struct.HostInfo.html
 pub fn get_host_info() -> Result<HostInfo, Error> {
     let x = host::get_uname()?;
 
     Ok(HostInfo {
         loadavg: cpu::get_loadavg().unwrap(),
-        uptime: get_uptime().unwrap().as_secs(),
         system: to_str(x.sysname.as_ptr()).to_owned(),
         os_version: host::get_os_version_from_uname(&x),
+        kernel_version: host::get_os_version_from_uname(&x),
         hostname: host::get_hostname_from_uname(&x),
+        uptime: get_uptime().unwrap().as_secs(),
     })
 }
 
 fn get_uptime() -> Result<Duration, Error> {
     let mut data = std::mem::MaybeUninit::<timeval>::uninit();
-    let mut mib: [i32; 2] = [1, 21];
+    let mut mib: [i32; 2] = [libc::CTL_KERN, libc::KERN_BOOTTIME];
 
     if unsafe {
         sysctl(
