@@ -1,6 +1,7 @@
 use crate::virt::Virtualization;
 
 mod containers;
+mod vm_dmi;
 
 /// Get the virtualization information of the current host
 ///
@@ -9,5 +10,6 @@ pub fn get_virt_info() -> Virtualization {
     containers::detect_openvz()
         .or_else(|_| containers::detect_wsl())
         .or_else(|_| containers::detect_systemd_container())
+        .or_else(|_| vm_dmi::detect_vm_dmi())
         .map_or(Virtualization::Unknown, |res| res)
 }
